@@ -110,7 +110,11 @@ class SystemState(schemattrdict):
         )
     )
 
-    default = dict(our_wg_pk=b'\x00' * 32, current_subnets={}, gateways=[],)
+    default = dict(
+        our_wg_pk=b'\x00' * 32,
+        current_subnets={},
+        gateways=[],
+    )
 
     @classmethod
     def read(cls, organize):
@@ -518,6 +522,9 @@ class Organize(attrdict):
           <arg type='s' name='value' direction='in'/>
           <arg type='s' name='response' direction='out'/>
         </method>
+        <method name='our_latest_descriptors'>
+          <arg type='s' name='descriptors' direction='out'/>
+        </method>
         <method name='get_vk_by_name'>
           <arg type='s' name='hostname' direction='in'/>
           <arg type='s' name='response' direction='out'/>
@@ -572,6 +579,7 @@ class Organize(attrdict):
         self._state.trigger_target = self.sys
         self._state.save = self.save
         self._state.debug_log = self.log.debug
+        self._latest_descriptors = {}
 
         if ctx.invoked_subcommand is None:
             self.run(monolithic=False)
@@ -596,6 +604,9 @@ class Organize(attrdict):
     def our_wg_pk(self):
         return str(self._keys.wg_Curve25519_pub_key)
 
+    def our_latest_descriptors(self):
+        return repr(jsonrepr(self._latest_descriptors))
+
     def _construct_service_descriptor(
         self, ip_addrs: str, vf: int
     ) -> Descriptor:
@@ -834,6 +845,11 @@ class Organize(attrdict):
         )
         self.discover.listen(current_ips)
         self.publish.listen(descriptors)
+        self._latest_descriptors = descriptors
+        self.log.info("Current IP(s): {}".format(current_ips))
+        self.log.info(
+            "Current descriptors: {}".format(self._latest_descriptors)
+        )
 
     @DualUse.method(opts=(click.argument('query', type=str),))
     def show_peer(self, query):
